@@ -12,7 +12,6 @@ const PopupMenu = imports.ui.popupMenu;
 const Gtk = imports.gi.Gtk;
 const GLib = imports.gi.GLib;
 const Signals = imports.signals;
-const Layout = imports.ui.layout;
 const Pango = imports.gi.Pango;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
@@ -74,7 +73,7 @@ const ApplicationMenuItem = new Lang.Class({
     },
 
     activate: function(event) {
-	this._app.open_new_window(event.get_time());
+	this._app.open_new_window(-1);
         this._button.selectCategory(null, null);
         this._button.menu.toggle();
 	this.parent(event);
@@ -203,23 +202,6 @@ const CategoryMenuItem = new Lang.Class({
     }
 });
 
-const HotCorner = new Lang.Class({
-    Name: 'HotCorner',
-    Extends: Layout.HotCorner,
-
-    _onCornerEntered : function() {
-        if (!this._entered) {
-            this._entered = true;
-            if (!Main.overview.animationInProgress) {
-                this._activationTime = Date.now() / 1000;
-                this.rippleAnimation();
-                Main.overview.toggle();
-            }
-        }
-        return false;
-    }
-});
-
 const ApplicationsMenu = new Lang.Class({
     Name: 'ApplicationsMenu',
     Extends: PopupMenu.PopupMenu,
